####################################################################
# DISPL.-BASED FIBER ELEMENTS, REINFORCED-CONCRETE, REF: 'RCFRAME' #
####################################################################
#
#
#    _____10__________11______                  _
#   |            |            |  
#   |2           |4           |6                    3.7m
#   |            |            |
#   |_____8______|_____9______|_____12_____     _
#   |            |            |            |
#   |            |            |            |
#   |1           |3           |5           |7       4.6m
#   |            |            |            |
#   |            |            |            |    _
#  ===          ===          ===          ===
#   |    7.3m    |    7.3m    |    7.3m    |
#
#


#set DeteriorationModelResponse 1.0
#
#set SnowLoadModelResponse 463076.292008934
#set IntensityModelLTResponse 0.1703937608554746
#set WindLoadModelResponse 247292.41297414
#
#set SnowLoadModelResponse 0
#set IntensityModelLTResponse 0
#set WindLoadModelResponse 0
#
#set Fy 300
#set Fc1 16
#set Fc2 22
#set Es 200000
#
#set IntColWidth 690
#set ExtColWidth 610


# comment out one of lines
#set displayMode "displayON"
set displayMode "displayOFF"


# CREATE THE MODEL BUILDERS
model BasicBuilder -ndm 2 -ndf 3


# DEFINE NODES
#    tag  X   Y
node  1 0     0
node  2 0     4600
node  3 0     8300
node  4 7300  0
node  5 7300  4600
node  6 7300  8300
node  7 14600 0
node  8 14600 4600
node  9 14600 8300
node 10 21900 0
node 11 21900 4600

# NODAL MASSES (in kilos)
#set mass 43.32314
#mass  2  [expr 1*$mass]   0.0   0.0
#mass  5  [expr 2*$mass]   0.0   0.0
#mass  8  [expr 2*$mass]   0.0   0.0
#mass  3  [expr 1*$mass]   0.0   0.0
#mass  6  [expr 2*$mass]   0.0   0.0
#mass  9  [expr 1*$mass]   0.0   0.0
#mass 11  [expr 1*$mass]   0.0   0.0


# SINGLE POINT CONSTRAINTS
#   node DX DY RZ
fix   1   1  1  1
fix   4   1  1  1
fix   7   1  1  1
fix  10   1  1  1

# DEFINE MATERIALS
# Cover concrete
set cover_fc $Fc1
set cover_fcu 0.0
set cover_epsco 0.002
set cover_epscu 0.006
set equi_cover [expr $cover_fc/$cover_epsco]
uniaxialMaterial Concrete01 1  -$cover_fc  -$cover_epsco  -$cover_fcu  -$cover_epscu
#uniaxialMaterial Elastic 1  $equi_cover

# Core concrete
set core_fc $Fc2
set core_fcu 18.0
set core_epsco 0.005
set core_epscu 0.02
set equi_core [expr $core_fc/$core_epsco]
uniaxialMaterial Concrete01 2  -$core_fc  -$core_epsco  -$core_fcu  -$core_epscu
#uniaxialMaterial Elastic 2  $equi_core

# Steel model
set steel_fy $Fy
set steel_E $Es
set steel_b 0.02
set H_iso 4081.6
uniaxialMaterial Steel01  3  $steel_fy  $steel_E  $steel_b    
uniaxialMaterial Hardening  4  $steel_E  $steel_fy  $H_iso 0.0  

# DEFINE SECTIONS
source RCsection.tcl

set scale 1.0

# Interior column section
#       id  h                   b               cover               coreID  coverID steelID numBars barArea                             nfCoreY nfCoreZ nfCoverY        nfCoverZ
RCsection   1   [expr $scale*$IntColWidth]  [expr $scale*610]   [expr $scale*65]    2       1       3       6       [expr 0.5*1000*$DeteriorationModelResponse] 12      1       14          1

# Exterior column section   
RCsection   2   [expr $scale*$ExtColWidth]  [expr $scale*610]   [expr $scale*65]    2       1       3       6       [expr 0.5*510*$DeteriorationModelResponse]      12      1       14          1

# Girder section
RCsection   3   [expr $scale*610]       [expr $scale*460]   [expr $scale*65]    1       1       3       4       [expr 0.5*650*$DeteriorationModelResponse]      12      1       12          1

# Interior column section
RCsection   4   [expr $scale*$IntColWidth]  [expr $scale*610]   [expr $scale*65]    2       1       4       6       [expr 0.5*1000*$DeteriorationModelResponse] 12      1       14          1


# NUMBER OF INTEGRATION POINTS
set nP 4

# GEOMETRIC TRANSFORMATION
geomTransf Linear 1
geomTransf PDelta 2

# DEFINE DISPLACEMENT BEAM-COLUMN ELEMENTS                
# Columns
#                      tag ndI ndJ  nPts secID transf
element dispBeamColumn  1   1   2    $nP   2      2
element dispBeamColumn  2   2   3    $nP   2      2
element dispBeamColumn  3   4   5    $nP   4      2
element dispBeamColumn  4   5   6    $nP   1      2
element dispBeamColumn  5   7   8    $nP   4      2
element dispBeamColumn  6   8   9    $nP   2      2
element dispBeamColumn  7  10  11    $nP   2      2


# Beams
element dispBeamColumn  8   2   5    $nP   3      1
element dispBeamColumn  9   5   8    $nP   3      1
element dispBeamColumn 10   3   6    $nP   3      1
element dispBeamColumn 11   6   9    $nP   3      1
element dispBeamColumn 12   8  11    $nP   3      1





set gLoad 0.425e6
# CONSTANT GRAVITY LOADS
pattern Plain 1 Constant {
   #    node  FX    FY             MZ
   load   2  0.0 [expr -$gLoad*2]  0.0 
   load   5  0.0 [expr -$gLoad*4]  0.0 
   load   8  0.0 [expr -$gLoad*3]  0.0 
   load   3  0.0 [expr -$gLoad*1]  0.0 
   load   6  0.0 [expr -$gLoad*2]  0.0 
   load   9  0.0 [expr -$gLoad*1]  0.0 
   load  11  0.0 [expr -$gLoad*1]  0.0 
}
constraints Transformation ;
numberer RCM;                          
system BandGeneral;                    
test NormDispIncr 1.0e-06 50;          
algorithm KrylovNewton
integrator LoadControl 0.1; 
analysis Static;            
analyze 10;                 
# maintain constant gravity loads and reset time to zero
loadConst -time 0.0

set sLoad $SnowLoadModelResponse
# CONSTANT SNOW LOADS
pattern Plain 3 Constant {
   #    node  FX    FY             MZ
   load   8  0.0 [expr -$sLoad*2]  0.0
   load   3  0.0 [expr -$sLoad*1]  0.0 
   load   6  0.0 [expr -$sLoad*2]  0.0 
   load   9  0.0 [expr -$sLoad*1]  0.0 
   load  11  0.0 [expr -$sLoad*1]  0.0  
}
constraints Transformation ;
numberer RCM;                          
system BandGeneral;                    
test NormDispIncr 1.0e-06 50;          
algorithm KrylovNewton
integrator LoadControl 0.1; 
analysis Static;            
analyze 10;                 
# maintain constant gravity loads and reset time to zero
loadConst -time 0.0


set w1 [expr 3*2*$gLoad+3*$sLoad]
set w2 [expr 2*2*$gLoad+2*2*$sLoad]
#puts $w1
#puts $w2
set V $IntensityModelLTResponse*($w1+$w2)
#dsitributinh according to the first mode shape (T1 = 0.5858403283504384)
set phi1 0.532
set phi2 1.0
set sum_w_phi [expr $w1*$phi1+$w2*$phi2]
pattern Plain 2 Linear {
   #    node         FX                      FY   MZ
   load   2 [expr $V*$w1*$phi1/$sum_w_phi]   0.0  0.0
   load   3 [expr $V*$w2*$phi2/$sum_w_phi]   0.0  0.0
}


set wLoad $WindLoadModelResponse
pattern Plain 4 Linear {
   #    node         FX      FY   MZ
   load   2 [expr $wLoad/2]  0.0  0.0
   load   3 [expr $wLoad/2]  0.0  0.0
}


if {$displayMode == "displayON"} { 
recorder display frame 100 0 800 500 -wipe
vup 0 1 0 # dirn defining up direction of view plane(ghab bordar movazi)
vpn 0 0 1 # direction of outward normal to view plane(amud bar safhe ghab)
prp 0 0 1 # eye location in local coord sys defined by viewing system
viewWindow -15000 15000 -15000 15000
display 1 1 50
}


# RECORDERS
recorder Node -file Drift.txt -time -node 3 -dof 1 disp;


# FINITE ELEMENT ANALYSIS MODEL
system BandGeneral
#system ProfileSPD
#constraints Plain
constraints Transformation
test NormDispIncr 1.0e-5  30
#algorithm Newton
algorithm KrylovNewton
numberer RCM
#integrator Newmark  0.5  0.25   0.0   0.0  0.005   0.0
integrator LoadControl  1  
#integrator NewmarkWithSensitivity  0.5  0.25   0.0   0.0   [expr 1.0/10.0]   0.0
#sensitivityIntegrator -definedAbove
#analysis Transient
analysis Static
integrator LoadControl  0.05   3   0.05    0.05
analyze 16
integrator LoadControl  0.02   3   0.02    0.02
analyze 10

#puts $SnowLoadModelResponse 
#puts $IntensityModelLTResponse 
#puts $WindLoadModelResponse